@@ -21,7 +21,7 @@ class ObjectPattern(BasePattern):
         self,
         origin: Type[TOrigin],
         limit: Tuple[str, ...] = (),
-        flag: Literal["urlget", "part", "json"] = "part",
+        flag: Literal["urlget", "part", "json", "space"] = "part",
         **suppliers: Callable,
     ):
         self._args = Args()
@@ -66,12 +66,16 @@ class ObjectPattern(BasePattern):
                         )
                     )
             self._names.append(name)
-            self._args.add_argument(name, value=anno, default=default)
+            self._args.add(name, value=anno, default=default)
         self.flag = flag
         if flag == "part":
             self._re_pattern = re.compile(
                 ";".join(f"(?P<{i}>.+?)" for i in self._names)
             )
+        elif flag == "space":
+            self._re_pattern = re.compile(
+                "( )".join(f"(?P<{i}>.+?)" for i in self._names)
+            )
         elif flag == "urlget":
             self._re_pattern = re.compile(
                 "&".join(f"{i}=(?P<{i}>.+?)" for i in self._names)
@@ -96,15 +100,10 @@ class ObjectPattern(BasePattern):
             raise MatchFailed(lang.type_error.format(target=input_.__class__))
         if not (mat := self._re_pattern.fullmatch(input_)):
             raise MatchFailed(lang.content_error.format(target=input_))
-        res = analyse_args(
-            self._args, list(mat.groupdict().values()), raise_exception=False
-        )
-        if not res:
+        if res := analyse_args(self._args, list(mat.groupdict().values()), raise_exception=False):
+            return self.origin(**res)
+        else:
             raise MatchFailed(lang.content_error.format(target=input_))
-        return self.origin(**res)
-
-    def __call__(self, *args, **kwargs):
-        return self.origin(*args, **kwargs)
 
     def __eq__(self, other):
         return isinstance(other, ObjectPattern) and self.origin == other.origin
